import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
/**
 * @license
 *
 * Copyright IBM Corp. 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { breakpoints as BXBreakpoints } from '@carbon/layout';
import root from 'window-or-global';
export let MQBreakpoints;
(function (MQBreakpoints) {
  MQBreakpoints["SM"] = "sm";
  MQBreakpoints["MD"] = "md";
  MQBreakpoints["LG"] = "lg";
  MQBreakpoints["XLG"] = "xlg";
  MQBreakpoints["MAX"] = "max";
})(MQBreakpoints || (MQBreakpoints = {}));
export let MQDirs;

/**
 * @param Base The base class.
 * @returns A mix-in implementing the logic for performing actions when the
 * viewport width crosses over configured Carbon breakpoints.
 */
(function (MQDirs) {
  MQDirs["MIN"] = "min";
  MQDirs["MAX"] = "max";
})(MQDirs || (MQDirs = {}));
const MediaQueryMixin = (Base, config) => {
  class MediaQueryMixinImpl extends Base {
    constructor(...args) {
      super(...args);
      /**
       * Configuration passed as argument into MediaQueryMixin.
       */
      _defineProperty(this, "_mqConfig", config);
      /**
       * A keyed list of MediaQueryList objects.
       */
      _defineProperty(this, "carbonBreakpoints", this._generateMediaQueriesByBreakpoint());
    }
    /**
     * Generates a list of MediaQueryList objects keyed by breakpoint identifiers.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/MediaQueryList
     */
    _generateMediaQueriesByBreakpoint() {
      const {
        _mqConfig: config
      } = this;
      const breakpoints = Object.keys(config);
      const queries = {};
      breakpoints.forEach(bp => {
        queries[bp] = root.matchMedia(`(${config[bp]}-width: ${BXBreakpoints[bp].width})`);
      });
      return queries;
    }
    /**
     * Sets up event listeners that fire any defined callback methods that
     * correspond to the breakpoint being crossed over.
     *
     * Example callback method names:
     *  - mediaQueryCallbackSM
     *  - mediaQueryCallbackLG
     *  - mediaQueryCallbackMaxMD
     *  - mediaQueryCallbackMaxMAX
     */
    _attachMediaQueryEventListeners() {
      const {
        _mqConfig: config,
        carbonBreakpoints
      } = this;
      Object.keys(carbonBreakpoints).forEach(bp => {
        const dir = config[bp] === MQDirs.MAX ? `${config[bp][0].toUpperCase()}${config[bp].slice(1)}` : '';
        const funcName = `mediaQueryCallback${dir}${bp.toUpperCase()}`;
        if (typeof this[funcName] === 'function') {
          this.carbonBreakpoints[bp].addEventListener('change', this[funcName].bind(this));
        } else {
          console.warn(`MediaQueryMixin: Element ${this.nodeName} has not defined a callback for the "${bp}" breakpoint. Please remove the breakpoint from the mixin configuration or implement the following method: ${funcName}`);
        }
      });
    }
    firstUpdated() {
      this._attachMediaQueryEventListeners();
      //@ts-ignore
      super.firstUpdated();
    }
  }
  return MediaQueryMixinImpl;
};
export default MediaQueryMixin;
//# sourceMappingURL=media-query.js.map
