/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { LitElement } from 'lit';
import { LocaleList } from '../../internal/vendor/@carbon/ibmdotcom-services-store/types/localeAPI';
import { BasicLink, BasicLinkSet, MastheadL1, L0MenuItem, MastheadProfileItem } from '../../internal/vendor/@carbon/ibmdotcom-services-store/types/translateAPI';
import { FOOTER_SIZE } from '../footer/footer';
import '../footer/footer-composite';
import './dotcom-shell';
/**
 * Component that renders dotcom shell from links, etc. data.
 *
 * @element c4d-dotcom-shell-composite
 * @csspart shell - The root element of the dotcom shell. Usage: `c4d-dotcom-shell-composite::part(shell)`
 */
declare class C4DDotcomShellComposite extends LitElement {
    /**
     * The render target of the footer contents.
     */
    private _footerRenderRoot;
    /**
     * The render target of the masthead contents.
     */
    private _mastheadRenderRoot;
    /**
     * The masthead element.
     */
    private _masthead?;
    /**
     * @returns The render root of the footer contents.
     */
    private _createFooterRenderRoot;
    /**
     * @returns The render root of the masthead contents.
     */
    private _createMastheadRenderRoot;
    /**
     * `true` if there is a profile.
     */
    hasProfile: boolean;
    /**
     * `true` if there is a search.
     */
    hasSearch: boolean;
    /**
     * `true` if there is a global banner.
     */
    hasBanner: boolean;
    /**
     * `true` to activate the search box. This goes to masthead.
     */
    activateSearch: boolean;
    /**
     * The profile items for authenticated state. This goes to masthead.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    authenticatedProfileItems?: MastheadProfileItem[];
    /**
     * The boolean to enable custom typeahead API.
     */
    customTypeaheadAPI: boolean;
    /**
     * The platform name. This goes to masthead.
     */
    platform?: string;
    /**
     * The platform url.
     */
    platformUrl?: string;
    /**
     * The g11n collator to use for sorting contry names. This goes to footer.
     */
    collatorCountryName: Intl.Collator;
    /**
     * The search results to show in the UI. This goes to masthead.
     * The data typically comes from our search service and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    currentSearchResults: string[];
    /**
     * `true` to omit the locale switcher button.
     */
    disableLocaleButton: boolean;
    /**
     * The throttle timeout to run query upon user input. This goes to masthead.
     */
    inputTimeout?: number;
    /**
     * The footer links. This goes to footer.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    footerLinks: BasicLinkSet[];
    /**
     * The language to show in the UI. This goes to footer.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    langDisplay?: string;
    /**
     * The language used for query. This goes to masthead and footer.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    language?: string;
    /**
     * The legal nav links. This goes to footer.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    legalLinks: BasicLink[];
    /**
     * The locale list. This goes to footer.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    localeList?: LocaleList;
    /**
     * The `aria-label` attribute for the top-level container. This goes to masthead.
     */
    mastheadAssistiveText?: string;
    /**
     * The `aria-label` attribute for the menu bar UI. This goes to masthead.
     */
    menuBarAssistiveText?: string;
    /**
     * The `aria-label` attribute for the header menu button in its active state. This goes to masthead.
     */
    menuButtonAssistiveTextActive?: string;
    /**
     * The `aria-label` attribute for the header menu button in its active state. This goes to masthead.
     */
    menuButtonAssistiveTextInactive?: string;
    /**
     * The English title of the selected nav item.
     */
    selectedMenuItem: string;
    /**
     * Footer size. This goes to footer.
     */
    footerSize?: FOOTER_SIZE;
    /**
     * `true` to open the search dropdown.. This goes to masthead.
     * The data typically comes from our search service and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    openSearchDropdown: boolean;
    /**
     * The profile items for unauthenticated state. This goes to masthead.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    unauthenticatedProfileItems?: MastheadProfileItem[];
    /**
     * Data for l1.
     */
    l1Data?: MastheadL1;
    /**
     * The navigation links. This goes to masthead.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     *
     * @deprecated Use l0Data instead.
     */
    navLinks?: L0MenuItem[];
    /**
     * The navigation links. This goes to masthead.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    l0Data?: L0MenuItem[];
    /**
     * The parameters passed to the search-with-typeahead for search scope
     */
    scopeParameters: any;
    /**
     * Value to display when the input has an empty `value`.
     */
    searchPlaceholder?: string;
    /**
     * The user authentication status. This goes to masthead.
     * The data typically comes from `@carbon/ibmdotcom-services` and thus you don't need to set this property by default,
     * but if you need an alternate way of integration (e.g. rendering Web Components tags in server-side) this property helps.
     */
    userStatus: string;
    firstUpdated(): void;
    update(changedProperties: any): void;
    updated(changedProperties: any): void;
    render(): import("lit-html").TemplateResult<1>;
    static styles: any;
}
export default C4DDotcomShellComposite;

//# sourceMappingURL=dotcom-shell-composite.d.ts.map
