import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { property, query, state } from 'lit/decorators.js';
import CDSAccordionItem from '@carbon/web-components/es/components/accordion/accordion-item.js';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import styles from "././filter-panel.css.js";
import StableSelectorMixin from "../../globals/mixins/stable-selector.js";
import C4DFilterPanelComposite from "./filter-panel-composite.js";
import C4DFilterPanelCheckbox from "./filter-panel-checkbox.js";
import C4DFilterPanelInputSelectItem from "./filter-panel-input-select-item.js";
import C4DFilterPanelInputSelect from "./filter-panel-input-select.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  prefix,
  stablePrefix: c4dPrefix
} = settings;
const viewAllClassName = `${c4dPrefix}-filter-group-item__view-all`;

/**
 * C4DFilterGroupItem renders each individual accordion
 *
 * @element c4d-filter-group-item
 */
let C4DFilterGroupItem = _decorate([customElement(`${c4dPrefix}-filter-group-item`)], function (_initialize, _StableSelectorMixin) {
  class C4DFilterGroupItem extends _StableSelectorMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DFilterGroupItem,
    d: [{
      kind: "get",
      static: true,
      key: "stableSelector",
      value:
      /**
       * Extends CDSAccordionItem component
       */
      function () {
        return `${c4dPrefix}--filter-group-item`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",
      value() {
        return styles;
      }
    }, {
      kind: "get",
      static: true,
      key: "viewAllSelector",
      value: // `styles` here is a `CSSResult` generated by custom WebPack loader
      function () {
        return `button.${viewAllClassName}`;
      }

      /**
       * The element containing the default slot.
       */
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--accordion__content`)],
      key: "accordionContent",
      value: void 0
    }, {
      kind: "field",
      decorators: [property({
        type: String,
        attribute: 'view-all-text'
      })],
      key: "viewAllText",
      value() {
        return 'View all';
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'max-filters'
      })],
      key: "maxFilters",
      value() {
        return 7;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Number,
        attribute: 'filter-cutoff'
      })],
      key: "filterCutoff",
      value() {
        return 5;
      }
    }, {
      kind: "field",
      decorators: [property({
        type: Boolean
      })],
      key: "allRevealed",
      value() {
        return false;
      }
    }, {
      kind: "field",
      decorators: [state()],
      key: "_focusedElement",
      value() {
        return null;
      }
    }, {
      kind: "method",
      key: "_needsViewAll",
      value:
      /**
       * The text for the button that reveals all filters in the group.
       */
      /**
       * The number of filters that can be shown without needing to hide any.
       */
      /**
       * The number of filters to show when not all filters are visible.
       */
      /**
       * Whether or not any hidden filters have been revealed.
       */
      /**
       * An element to set focus to on reveal.
       */
      /**
       * Whether or not to add view all button functionality.
       */
      function _needsViewAll() {
        return this.children.length > this.maxFilters;
      }

      /**
       * Checks if any filters beyond the cutoff point have been selected.
       */
    }, {
      kind: "method",
      key: "_hasHiddenActiveFilter",
      value: function _hasHiddenActiveFilter() {
        const {
          children,
          filterCutoff
        } = this;
        let result = false;
        [...children].slice(filterCutoff, children.length).forEach(elem => {
          if (elem instanceof C4DFilterPanelCheckbox) {
            if (elem.checked) {
              result = true;
            }
          }
          if (elem instanceof C4DFilterPanelInputSelectItem || elem instanceof C4DFilterPanelInputSelect) {
            if (elem.selected) {
              result = true;
            }
          }
        });
        return result;
      }

      /**
       * Hides or reveals excess filters.
       */
    }, {
      kind: "method",
      key: "_handleAllRevealed",
      value: function _handleAllRevealed(revealed) {
        const {
          children,
          filterCutoff,
          accordionContent
        } = this;
        const hasHiddenActiveFilter = this._hasHiddenActiveFilter();
        [...children].slice(filterCutoff, children.length).forEach(elem => {
          elem.style.display = revealed || hasHiddenActiveFilter ? '' : 'none';
        });
        if (!revealed && !hasHiddenActiveFilter) {
          accordionContent.appendChild(this._renderViewAll());
        }
        this._dispatchViewAllEvent(revealed);
      }

      /**
       * Generates a view all button.
       */
    }, {
      kind: "method",
      key: "_renderViewAll",
      value: function _renderViewAll() {
        const {
          children,
          filterCutoff
        } = this;
        const viewAll = document.createElement('button');
        viewAll.classList.add(viewAllClassName, `${prefix}--btn--ghost`);
        viewAll.type = 'button';
        viewAll.innerText = this.viewAllText;
        viewAll.addEventListener('click', e => {
          this.allRevealed = true;
          if (e.target instanceof HTMLElement) {
            e.target.remove();
          }
          const firstHidden = children[filterCutoff];
          if (firstHidden instanceof HTMLElement) {
            this._focusedElement = firstHidden;
          }
        }, {
          passive: true,
          once: true
        });
        return viewAll;
      }

      /**
       * Dispatches a custom event that notifies listeners whether or not this
       * filter group has all options revealed.
       */
    }, {
      kind: "method",
      key: "_dispatchViewAllEvent",
      value: function _dispatchViewAllEvent(removed) {
        const {
          eventViewAll
        } = this.constructor;
        this.dispatchEvent(new CustomEvent(eventViewAll, {
          bubbles: true,
          cancelable: true,
          composed: true,
          detail: {
            id: this.title,
            value: removed
          }
        }));
      }

      /**
       * Retrieves view all state stored in the filter panel composite. Returns
       * internal value if no cache is found.
       */
    }, {
      kind: "method",
      key: "_getCachedViewAllValue",
      value: function _getCachedViewAllValue() {
        const {
          allRevealed,
          title
        } = this;
        let result = allRevealed;
        const filterPanel = this.closest('c4d-filter-panel');
        if (filterPanel !== null) {
          // Indicates this is composite's duplicated content.
          let parentHost;
          const parent = filterPanel.parentNode;
          if (parent instanceof ShadowRoot) {
            parentHost = parent.host;
          }
          if (parentHost instanceof C4DFilterPanelComposite) {
            const match = parentHost._filterGroupsAllRevealed.find(entry => {
              return entry.id === title;
            });
            if (match !== undefined) {
              result = match.value;
            }
          }
        }
        return result;
      }
    }, {
      kind: "method",
      key: "firstUpdated",
      value: function firstUpdated() {
        if (this._needsViewAll()) {
          this.allRevealed = this._getCachedViewAllValue();
        }
      }
    }, {
      kind: "method",
      key: "updated",
      value: function updated(_changedProperties) {
        const {
          allRevealed,
          _focusedElement
        } = this;
        if (this._needsViewAll()) {
          const prevOpen = _changedProperties.get('open');
          const hasAllRevealed = _changedProperties.has('allRevealed');
          const prevAllRevealed = _changedProperties.get('allRevealed');

          // Reset `allRevealed` on accordion close.
          if (prevOpen) {
            this.allRevealed = this._hasHiddenActiveFilter() || false;
          }

          // Respect `allRevealed` attribute.
          if (hasAllRevealed) {
            if (prevAllRevealed === undefined) {
              this._handleAllRevealed(this._getCachedViewAllValue());
            } else {
              this._handleAllRevealed(allRevealed);
              if (allRevealed && _focusedElement instanceof HTMLElement) {
                _focusedElement.focus();
                this._focusedElement = null;
              }
            }
          }
        }
      }

      /**
       * The name of the event that fires when the view all button is toggled.
       */
    }, {
      kind: "get",
      static: true,
      key: "eventViewAll",
      value: function () {
        return `${c4dPrefix}-filter-group-view-all-toggle`;
      }
    }]
  };
}, StableSelectorMixin(CDSAccordionItem));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DFilterGroupItem;
//# sourceMappingURL=filter-group-item.js.map
