import _decorate from "@babel/runtime/helpers/esm/decorate";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2024
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import pickBy from 'lodash-es/pickBy.js';
import { bindActionCreators } from 'redux';
import settings from '@carbon/ibmdotcom-utilities/es/utilities/settings/settings.js';
import store from '../../internal/vendor/@carbon/ibmdotcom-services-store/store.js';
import { loadLanguage, setLanguage } from '../../internal/vendor/@carbon/ibmdotcom-services-store/actions/localeAPI.js';
import { loadTranslation } from '../../internal/vendor/@carbon/ibmdotcom-services-store/actions/translateAPI.js';
import { loadUserStatus } from '../../internal/vendor/@carbon/ibmdotcom-services-store/actions/profileAPI.js';
import ConnectMixin from "../../globals/mixins/connect.js";
import C4DMastheadComposite from "./masthead-composite.js";
import { carbonElement as customElement } from '@carbon/web-components/es/globals/decorators/carbon-element.js';
const {
  stablePrefix: c4dPrefix
} = settings;

/**
 * The Redux state used for `<c4d-masthead-container>`.
 */

/**
 * The properties for `<c4d-masthead-container>` from Redux state.
 */

/**
 * The Redux actions used for `<c4d-masthead-container>.
 */

/**
 * @param state The Redux state for masthead.
 * @param self A reference to the masthead composite instance.
 * @returns The converted version of the given state, tailored for `<c4d-masthead-container>`.
 */
export function mapStateToProps(state, self) {
  var _translations$languag7, _translations$languag8;
  const {
    localeAPI,
    translateAPI,
    profileAPI
  } = state;
  const {
    language
  } = localeAPI !== null && localeAPI !== void 0 ? localeAPI : {};
  const {
    translations
  } = translateAPI !== null && translateAPI !== void 0 ? translateAPI : {};
  const {
    request
  } = profileAPI !== null && profileAPI !== void 0 ? profileAPI : {};
  const getUserL0Data = self.getL0Data.bind(self);

  // Attempt to collect data from current/new and deprecated locations.
  let endpointl0Data;
  let profileItems;
  if (language) {
    var _translations$languag, _translations$languag2, _translations$languag3, _translations$languag4, _translations$languag5, _translations$languag6;
    endpointl0Data = {
      current: translations === null || translations === void 0 || (_translations$languag = translations[language]) === null || _translations$languag === void 0 || (_translations$languag = _translations$languag.masthead) === null || _translations$languag === void 0 ? void 0 : _translations$languag.nav,
      deprecated: translations === null || translations === void 0 || (_translations$languag2 = translations[language]) === null || _translations$languag2 === void 0 || (_translations$languag2 = _translations$languag2.mastheadNav) === null || _translations$languag2 === void 0 ? void 0 : _translations$languag2.links
    };
    profileItems = {
      authenticated: {
        current: translations === null || translations === void 0 || (_translations$languag3 = translations[language]) === null || _translations$languag3 === void 0 || (_translations$languag3 = _translations$languag3.masthead) === null || _translations$languag3 === void 0 || (_translations$languag3 = _translations$languag3.profileMenu) === null || _translations$languag3 === void 0 ? void 0 : _translations$languag3.authenticated,
        deprecated: translations === null || translations === void 0 || (_translations$languag4 = translations[language]) === null || _translations$languag4 === void 0 || (_translations$languag4 = _translations$languag4.profileMenu) === null || _translations$languag4 === void 0 ? void 0 : _translations$languag4.signedin
      },
      unauthenticated: {
        current: translations === null || translations === void 0 || (_translations$languag5 = translations[language]) === null || _translations$languag5 === void 0 || (_translations$languag5 = _translations$languag5.masthead) === null || _translations$languag5 === void 0 || (_translations$languag5 = _translations$languag5.profileMenu) === null || _translations$languag5 === void 0 ? void 0 : _translations$languag5.unauthenticated,
        deprecated: translations === null || translations === void 0 || (_translations$languag6 = translations[language]) === null || _translations$languag6 === void 0 || (_translations$languag6 = _translations$languag6.profileMenu) === null || _translations$languag6 === void 0 ? void 0 : _translations$languag6.signedout
      }
    };
  }
  return pickBy({
    // Respect user-set L0 data. Otherwise, progressively enhance to new shape.
    l0Data: !language || getUserL0Data() ? undefined : endpointl0Data.current || endpointl0Data.deprecated,
    // Progressively enhance to new profile items shape.
    authenticatedProfileItems: !language ? undefined : profileItems.authenticated.current || profileItems.authenticated.deprecated,
    unauthenticatedProfileItems: !language ? undefined : profileItems.unauthenticated.current || profileItems.unauthenticated.deprecated,
    contactUsButton: !language ? undefined : translations === null || translations === void 0 || (_translations$languag7 = translations[language]) === null || _translations$languag7 === void 0 || (_translations$languag7 = _translations$languag7.masthead) === null || _translations$languag7 === void 0 ? void 0 : _translations$languag7.contact,
    logoData: !language ? undefined : translations === null || translations === void 0 || (_translations$languag8 = translations[language]) === null || _translations$languag8 === void 0 || (_translations$languag8 = _translations$languag8.masthead) === null || _translations$languag8 === void 0 ? void 0 : _translations$languag8.logo,
    userStatus: request === null || request === void 0 ? void 0 : request.user,
    language
  }, value => value !== undefined);
}

/**
 * @param dispatch The Redux `dispatch()` API.
 * @returns The methods in `<c4d-masthead-container>` to dispatch Redux actions.
 */
export function mapDispatchToProps(dispatch) {
  return bindActionCreators({
    _loadLanguage: loadLanguage,
    _setLanguage: setLanguage,
    _loadTranslation: loadTranslation,
    _loadUserStatus: loadUserStatus
  }, dispatch // TS definition of `bindActionCreators()` seems to have no templated `Dispatch`
  );
}

/**
 * Container component for masthead.
 *
 * @element c4d-masthead-container
 */
let C4DMastheadContainer = _decorate([customElement(`${c4dPrefix}-masthead-container`)], function (_initialize, _ConnectMixin) {
  class C4DMastheadContainer extends _ConnectMixin {
    constructor(...args) {
      super(...args);
      _initialize(this);
    }
  }
  return {
    F: C4DMastheadContainer,
    d: []
  };
}, ConnectMixin(store, mapStateToProps, mapDispatchToProps)(C4DMastheadComposite));
/* @__GENERATE_REACT_CUSTOM_ELEMENT_TYPE__ */
export default C4DMastheadContainer;
//# sourceMappingURL=masthead-container.js.map
