import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

import { render } from 'lit';
/**
 * @param elem The starting element.
 * @param selector The CSS selector.
 * @returns {Element}
 *   The closest ancestor node of the given element that matches the given selector, crossing Shadow DOM boundary.
 */
const closestComposed = (elem, selector) => {
  const found = elem.closest(selector);
  if (found) {
    return found;
  }
  const {
    host
  } = elem.getRootNode();
  if (host) {
    return closestComposed(host, selector);
  }
  return null;
};

/**
 * @param Base The base class.
 * @returns A mix-in that allows rendering modal, that should typically be rendered to a DOM node outside the component.
 */
const ModalRenderMixin = Base => {
  class ModalRenderMixinImpl extends Base {
    constructor(...args) {
      super(...args);
      /**
       * `true` if this component is disconnected from render tree after creation.
       *
       * @private
       */
      _defineProperty(this, "_disconnectedAfterCreation", false);
      /**
       * The render target of the modal.
       */
      _defineProperty(this, "modalRenderRoot", null);
      /**
       * Defines properties which should trigger modal renders. If none are specified,
       * modal renders on any property update.
       */
      _defineProperty(this, "modalTriggerProps", []);
    }
    // Not using TypeScript `private` due to: microsoft/TypeScript#17744

    /**
     * Creates and renders the modal
     *
     * @private
     */
    // Not using TypeScript `private` due to: microsoft/TypeScript#17744
    _createAndRenderModal() {
      if (!this.modalRenderRoot) {
        this.modalRenderRoot = this.createModalRenderRoot();
      }
      const {
        modalRenderRoot
      } = this;
      if (modalRenderRoot) {
        render(this.renderModal(), modalRenderRoot);
      }
    }

    /**
     * @returns The template of the modal.
     */

    /**
     * The DOM element to put the modal into.
     */
    get container() {
      const {
        selectorContainer
      } = this.constructor;
      return closestComposed(this, selectorContainer) || this.ownerDocument.body;
    }

    /**
     * @returns The render root of the modal.
     */
    createModalRenderRoot() {
      const {
        container,
        ownerDocument: doc
      } = this;
      const div = doc.createElement('div');
      div.style.display = 'contents'; // Prevents render-root `<div>` from being rendered
      container.appendChild(div);
      return div;
    }
    connectedCallback() {
      // TODO: Figure out how to inherit `LitElement` for this mix-in class
      // @ts-ignore
      super.connectedCallback();
      if (this._disconnectedAfterCreation) {
        this._disconnectedAfterCreation = false;
        this._createAndRenderModal();
      }
    }
    disconnectedCallback() {
      if (this.modalRenderRoot) {
        this.modalRenderRoot.remove();
        this.modalRenderRoot = null;
      }
      // TODO: Figure out how to inherit `LitElement` for this mix-in class
      // @ts-ignore
      super.disconnectedCallback();
      this._disconnectedAfterCreation = true;
    }
    update(changedProperties) {
      const {
        modalTriggerProps
      } = this;
      // TODO: Figure out how to inherit `LitElement` for this mix-in class
      // @ts-ignore
      super.update(changedProperties);
      if (!this._disconnectedAfterCreation) {
        if (modalTriggerProps.length > 0) {
          // React only on updates to specified properties.
          const changedPropNames = Array.from(changedProperties.keys());
          const matches = modalTriggerProps.filter(prop => changedPropNames.includes(prop));
          if (matches.length > 0) {
            this._createAndRenderModal();
          }
        } else {
          // React on every property update.
          this._createAndRenderModal();
        }
      }
    }

    /**
     * The CSS selector to find the element to put the modal in.
     */
    static get selectorContainer() {
      return '[data-modal-container]';
    }
  }
  return ModalRenderMixinImpl;
};
export default ModalRenderMixin;
//# sourceMappingURL=modal-render.js.map
