import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * @param Base The base class.
 * @returns A mix-in that sets its defined stable selector.
 */
const StableSelectorMixin = Base => {
  class StableSelectorMixinImpl extends Base {
    constructor(...args) {
      super(...args);
      /**
       * The element that will be targeted for transposition
       *
       * @private
       */
      /**
       * The string array element containing the alternate attributes to target
       *
       * @private
       */
      /**
       * Mutation observer to watch for attribute changes
       *
       * @private
       */
      _defineProperty(this, "_mutationObserver", null);
    }
    connectedCallback() {
      // TS seems to miss `HTMLElement.prototype.connectedCallback()` definition
      // @ts-ignore
      super.connectedCallback();
      const {
        stableSelector
      } = this.constructor;
      if (stableSelector) {
        this.dataset.autoid = stableSelector;
      }
      this._cleanAndCreateMutationObserver({
        create: true
      });
      window.requestAnimationFrame(() => {
        if (!this.linkNode) {
          this.transposeAttributes();
        }
      });
    }
    disconnectedCallback() {
      this._cleanAndCreateMutationObserver();
    }

    /**
     * Function to transpose any data-* attributes to the anchor tag in the shadow dom.
     *
     * @param linkNodeArg optional argument to pass in custom element to target instead of an anchor link
     * @param altAttributesArg optional argument to target additional attributes to transpose
     */
    transposeAttributes(linkNodeArg, altAttributesArg) {
      var _this$shadowRoot;
      this.linkNode = linkNodeArg;
      this.altAttributes = altAttributesArg;
      if (!this.linkNode) {
        this.querySelectorAll('*').forEach(e => {
          var _e$shadowRoot;
          const anchor = (_e$shadowRoot = e.shadowRoot) === null || _e$shadowRoot === void 0 ? void 0 : _e$shadowRoot.querySelector('a');
          if (anchor) {
            this.linkNode = anchor;
          }
        });
      }
      this.linkNode = this.linkNode || ((_this$shadowRoot = this.shadowRoot) === null || _this$shadowRoot === void 0 ? void 0 : _this$shadowRoot.querySelector('a'));
      const scrapedAttributes = [].filter.call(this.attributes, at => /^data-/.test(at.name) && at.name !== 'data-autoid' || this.altAttributes && this.altAttributes.includes(at.name));
      scrapedAttributes.forEach(e => {
        if (this.linkNode) {
          var _this$linkNode;
          (_this$linkNode = this.linkNode) === null || _this$linkNode === void 0 || _this$linkNode.setAttribute(e.name, e.value);
        }
      });
    }

    /**
     * Cleans-up and creates the mutation observer.
     *
     * @param [options] The options.
     * @param [options.create] `true` to create the new mutation observer.
     */
    _cleanAndCreateMutationObserver({
      create
    } = {}) {
      if (this._mutationObserver) {
        this._mutationObserver.disconnect();
        this._mutationObserver = null;
      }
      if (create) {
        var _this$_mutationObserv;
        this._mutationObserver = new MutationObserver(mutations => {
          mutations.forEach(mutation => {
            if (mutation.type === 'attributes') {
              if (this.linkNode) {
                this.transposeAttributes(this.linkNode);
              }
            }
          });
        });
        (_this$_mutationObserv = this._mutationObserver) === null || _this$_mutationObserv === void 0 || _this$_mutationObserv.observe(this, {
          attributes: true
        });
      }
    }

    /**
     * The stable selector for this component.
     */
  }
  return StableSelectorMixinImpl;
};
export default StableSelectorMixin;
//# sourceMappingURL=stable-selector.js.map
